# ID Broker plugins

## Intro
This repository contains a Debian source package for the ID Broker systems.
The following binary Debian packages are created from it:

* `id-broker-common`: scripts and code used in multiple other packages
* `ucs-test-id-broker-common`: tests for `id-broker-common`
* `id-broker-ldap-schema`: installation of LDAP schema, LDAP ACLs and extended UDM properties
* `id-broker-provisioning-api-plugin`: plugin for the `ucsschool-apis` app with the REST resources of the Provisioning API
* `id-broker-self-disclosure-api-plugin`: plugin for the `ucsschool-apis` app with the REST resources of the Self-Disclosure API

The Provisioning API and the Self-Disclosure APIs connect to the Kelvin REST API, the UDM REST API and OpenLDAP (directly) to CRUD users, groups and OUs.
The setup of those connections is configured through join scripts.

High level and also in-depth information on the ID Broker project can be found in the following documentation:

* Architecture documentation: https://univention.gitpages.knut.univention.de/id-broker/architecture-documentation/
* Operations manual (for Linet): https://univention.gitpages.knut.univention.de/id-broker/operations-manual/
* Documentation for school authorities: *TODO* -> https://git.knut.univention.de/univention/ucsschool/-/issues/352
* Documentation for service providers: *TODO* -> https://git.knut.univention.de/univention/ucsschool/-/issues/506

## Installation & configuration

Installation instructions for the *Self-Disclosure API* can be found here: https://univention.gitpages.knut.univention.de/id-broker/operations-manual/installation.html#backup-self-disclosure-api

Installation instructions for the *Provisioning API* can be found here: https://univention.gitpages.knut.univention.de/id-broker/operations-manual/installation.html#backup-provisioning-api

### Kelvin REST API

The Kelvin REST API will be configured by the join scripts to include the extended properties for the service provider specific pseudonyms (in `idBrokerPseudonym____`), the source objects `entryUUID` (in `ucsschoolRecordUID`), and the school authority (in `ucsschoolSourceUID`) it originates from.
The extended properties mapping configuration is in `/etc/ucsschool/kelvin/mapped_udm_properties.json`.

Additionally, the join scripts configure Kelvin to accept usernames with a length of up to `50` characters.
This is configured on `/var/lib/ucs-school-import/configs/kelvin.json`.

### Provisioning API and Self-Disclosure API configuration

It is assumed that the Provisioning API and the Self-Disclosure API are installed in different systems (UCS `backup` role).

The Provisioning API and Self-Disclosure API plugins for the `ucsschool-apis` apps are enabled in `/etc/ucsschool/apis/settings.json`.
This is also where their authentication strategies (provided by the `auth` plugin) are configured.

The APIs access the Kelvin REST API using the `ucsschool-apis` apps machine account.
The credentials are stored in `/etc/ucsschool/apis/id-broker/provisioning-api.json` and `/etc/ucsschool/apis/id-broker/self-disclosure-api.json` respectively.

## Swagger UI

Both REST APIs can be accessed interactively through the Swagger UI at https://FQDN/ucsschool/apis/docs
